@@ -51,6 +51,16 @@ def kraken_get(url, params={}, headers={}):
     return authenticated_get(url, params, headers)
 
 
+def gql_post(query):
+    url = "https://gql.twitch.tv/gql"
+    response = authenticated_post(url, data=query).json()
+
+    if "errors" in response:
+        raise GQLError(response["errors"])
+
+    return response
+
+
 def gql_query(query):
     url = "https://gql.twitch.tv/gql"
     response = authenticated_post(url, json={"query": query}).json()
@@ -133,6 +143,26 @@ def get_clip(slug):
     return response["data"]["clip"]
 
 
+def get_clip_access_token(slug):
+    query = """
+    {{
+        "operationName": "VideoAccessToken_Clip",
+        "variables": {{
+            "slug": "{slug}"
+        }},
+        "extensions": {{
+            "persistedQuery": {{
+                "version": 1,
+                "sha256Hash": "36b89d2507fce29e5ca551df756d27c1cfe079e2609642b4390aa4c35796eb11"
+            }}
+        }}
+    }}
+    """
+
+    response = gql_post(query.format(slug=slug).strip())
+    return response["data"]["clip"]
+
+
 def get_channel_clips(channel_id, period, limit, after=None):
     """
     List channel clips.
@@ -263,6 +293,10 @@ def get_channel_videos(channel_id, limit, sort, type="archive", game_ids=[], aft
     })
 
     response = gql_query(query)
+
+    if not response["data"]["user"]:
+        raise ConsoleError("Channel {} not found".format(channel_id))
+
     return response["data"]["user"]["videos"]
 
 
